@@ -106,13 +106,7 @@ class _Project(_Base):
                 print(r.text)
             r.raise_for_status()
 
-            try:
-                self._make_request('POST', url)
-            except Exception as e:
-                if str(e).find('Model will not be uploaded.'):
-                    print('Model not sampled.')
-                else:
-                    raise e
+            self._make_request('POST', url, print_error=False, throw_error=False)
 
     """
         Uploads pre-intersected list of ids to newly created project.
